@@ -320,11 +320,16 @@ class Git(object):
         # progressParam = {'fetch': {'part': 4, 'end': False},
         #                  'checkout': {'part': 4, 'startpart': 3}}
 
+    @staticmethod
+    def is_private_url(url):
+        return Git.parse_url(url)[0] == Git.GitProtocol.SSH
+
     def trimRepository(self, rpath, cb_progress=None):
         """
         Удалить в репозитории лишнии объекты
         """
         git_dir = self._gitDir(rpath)
+
         head_info = self.getFetchHeadInfo(git_dir)
         if not head_info or not head_info.get('reference', ''):
             return False
